voxelToWorld: Transform points between voxel and ``world'' coordinates
Description
These functions are used to transform points from dimensionless pixel or
voxel coordinates to ``real-world'' coordinates, typically in millimetres,
and back. Actual pixel units can be obtained using the
pixunits function.Usage
voxelToWorld(points, image, simple = FALSE, ...)worldToVoxel(points, image, simple = FALSE, ...)
Arguments
points
A vector giving the coordinates of a point, or a matrix with
one point per row.
image
The image in whose space the points are given.
simple
A logical value: if TRUE then the transformation is
performed simply by rescaling the points according to the voxel dimensions
recorded in the image. Otherwise the full xform matrix is used.
...
Additional arguments to xform. Value
- A vector or matrix of transformed points.